@@ -3,17 +3,19 @@
 # changes made to this file will be lost the next time ruby is built.
 
 module Config
-  RUBY_VERSION == "1.8.1" or
-    raise "ruby lib version (1.8.1) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION == "1.8.5" or
+    raise "ruby lib version (1.8.5) doesn't match executable version (#{RUBY_VERSION})"
 
-  TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.8/hppa\-openbsd3\.6\Z', '')
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/1.8/hppa-openbsd4.2")
   DESTDIR = '' unless defined? DESTDIR
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
-  CONFIG["srcdir"] = "/usr/obj/ports/ruby-1.8.1/ruby-1.8.1"
+  CONFIG["INSTALL"] = '/usr/bin/install -c -o root -g bin'
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
-  CONFIG["ruby_install_name"] = "ruby"
   CONFIG["EXEEXT"] = ""
+  CONFIG["ruby_install_name"] = "ruby"
+  CONFIG["RUBY_INSTALL_NAME"] = "ruby"
+  CONFIG["RUBY_SO_NAME"] = "ruby"
   CONFIG["SHELL"] = "/bin/sh"
   CONFIG["PATH_SEPARATOR"] = ":"
   CONFIG["PACKAGE_NAME"] = ""
@@ -25,61 +27,73 @@ module Config
   CONFIG["bindir"] = "$(exec_prefix)/bin"
   CONFIG["sbindir"] = "$(exec_prefix)/sbin"
   CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
-  CONFIG["datadir"] = "$(prefix)/share"
+  CONFIG["datarootdir"] = "$(prefix)/share"
+  CONFIG["datadir"] = "$(datarootdir)"
   CONFIG["sysconfdir"] = "$(DESTDIR)/etc"
   CONFIG["sharedstatedir"] = "$(prefix)/com"
   CONFIG["localstatedir"] = "$(prefix)/var"
-  CONFIG["libdir"] = "$(exec_prefix)/lib"
   CONFIG["includedir"] = "$(prefix)/include"
   CONFIG["oldincludedir"] = "/usr/include"
-  CONFIG["infodir"] = "$(prefix)/info"
-  CONFIG["mandir"] = "$(prefix)/man"
+  CONFIG["docdir"] = "$(datarootdir)/doc/$(PACKAGE)"
+  CONFIG["infodir"] = "$(DESTDIR)/usr/local/info"
+  CONFIG["htmldir"] = "$(docdir)"
+  CONFIG["dvidir"] = "$(docdir)"
+  CONFIG["pdfdir"] = "$(docdir)"
+  CONFIG["psdir"] = "$(docdir)"
+  CONFIG["libdir"] = "$(exec_prefix)/lib"
+  CONFIG["localedir"] = "$(datarootdir)/locale"
+  CONFIG["mandir"] = "$(DESTDIR)/usr/local/man"
+  CONFIG["ECHO_C"] = ""
+  CONFIG["ECHO_N"] = "-n"
+  CONFIG["ECHO_T"] = ""
+  CONFIG["LIBS"] = "-lm "
   CONFIG["build_alias"] = ""
   CONFIG["host_alias"] = ""
   CONFIG["target_alias"] = ""
-  CONFIG["ECHO_C"] = "\\c"
-  CONFIG["ECHO_N"] = ""
-  CONFIG["ECHO_T"] = ""
-  CONFIG["LIBS"] = "-lm "
   CONFIG["MAJOR"] = "1"
   CONFIG["MINOR"] = "8"
-  CONFIG["TEENY"] = "1"
-  CONFIG["build"] = "hppa-unknown-openbsd3.6"
+  CONFIG["TEENY"] = "5"
+  CONFIG["build"] = "hppa-unknown-openbsd4.2"
   CONFIG["build_cpu"] = "hppa"
   CONFIG["build_vendor"] = "unknown"
-  CONFIG["build_os"] = "openbsd3.6"
-  CONFIG["host"] = "hppa-unknown-openbsd3.6"
+  CONFIG["build_os"] = "openbsd4.2"
+  CONFIG["host"] = "hppa-unknown-openbsd4.2"
   CONFIG["host_cpu"] = "hppa"
   CONFIG["host_vendor"] = "unknown"
-  CONFIG["host_os"] = "openbsd3.6"
-  CONFIG["target"] = "hppa-unknown-openbsd3.6"
+  CONFIG["host_os"] = "openbsd4.2"
+  CONFIG["target"] = "hppa-unknown-openbsd4.2"
   CONFIG["target_cpu"] = "hppa"
   CONFIG["target_vendor"] = "unknown"
-  CONFIG["target_os"] = "openbsd3.6"
+  CONFIG["target_os"] = "openbsd4.2"
   CONFIG["CC"] = "cc"
-  CONFIG["ac_ct_CC"] = "cc"
-  CONFIG["CFLAGS"] = "-O2    -fPIC"
+  CONFIG["CFLAGS"] = "-O2 -pipe  -fPIC"
   CONFIG["LDFLAGS"] = " -Wl,-E"
-  CONFIG["CPPFLAGS"] = ""
+  CONFIG["CPPFLAGS"] = "-DOPENSSL_NO_STATIC_ENGINE"
   CONFIG["OBJEXT"] = "o"
   CONFIG["CPP"] = "cc -E"
-  CONFIG["EGREP"] = "grep -E"
+  CONFIG["GREP"] = "/usr/bin/grep"
+  CONFIG["EGREP"] = "/usr/bin/grep -E"
   CONFIG["GNU_LD"] = "yes"
   CONFIG["CPPOUTFILE"] = "-o conftest.i"
   CONFIG["OUTFLAG"] = "-o "
   CONFIG["YACC"] = "yacc"
+  CONFIG["YFLAGS"] = ""
   CONFIG["RANLIB"] = "ranlib"
-  CONFIG["ac_ct_RANLIB"] = "ranlib"
   CONFIG["AR"] = "ar"
-  CONFIG["ac_ct_AR"] = "ar"
+  CONFIG["AS"] = "as"
+  CONFIG["ASFLAGS"] = ""
   CONFIG["NM"] = ""
-  CONFIG["ac_ct_NM"] = ""
   CONFIG["WINDRES"] = ""
-  CONFIG["ac_ct_WINDRES"] = ""
   CONFIG["DLLWRAP"] = ""
-  CONFIG["ac_ct_DLLWRAP"] = ""
+  CONFIG["OBJDUMP"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["SET_MAKE"] = ""
+  CONFIG["INSTALL_PROGRAM"] = "install -c -s -o root -g bin -m 555"
+  CONFIG["INSTALL_SCRIPT"] = "install -c -o root -g bin -m 555"
+  CONFIG["INSTALL_DATA"] = "install -c -o root -g bin -m 444"
+  CONFIG["RM"] = "rm -f"
+  CONFIG["CP"] = "cp"
+  CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["LIBOBJS"] = ""
   CONFIG["ALLOCA"] = ""
   CONFIG["DLDFLAGS"] = ""
@@ -91,29 +105,32 @@ module Config
   CONFIG["DLEXT2"] = ""
   CONFIG["LIBEXT"] = "a"
   CONFIG["LINK_SO"] = ""
-  CONFIG["LIBPATHFLAG"] = " -L%s"
-  CONFIG["RPATHFLAG"] = ""
+  CONFIG["LIBPATHFLAG"] = " -L'%1$-s'"
+  CONFIG["RPATHFLAG"] = " -Wl,-R'%1$-s'"
+  CONFIG["LIBPATHENV"] = "LD_LIBRARY_PATH"
+  CONFIG["TRY_LINK"] = ""
   CONFIG["STRIP"] = "strip"
   CONFIG["EXTSTATIC"] = ""
   CONFIG["setup"] = "Setup"
   CONFIG["MINIRUBY"] = "./miniruby$(EXEEXT)"
-  CONFIG["PREP"] = ""
+  CONFIG["PREP"] = "miniruby$(EXEEXT)"
+  CONFIG["RUNRUBY"] = "$(MINIRUBY) $(srcdir)/runruby.rb --extout=$(EXTOUT) --"
+  CONFIG["EXTOUT"] = ".ext"
   CONFIG["ARCHFILE"] = ""
-  CONFIG["XCFLAGS"] = ""
+  CONFIG["RDOCTARGET"] = ""
+  CONFIG["XCFLAGS"] = " -DRUBY_EXPORT"
   CONFIG["XLDFLAGS"] = " -L."
   CONFIG["LIBRUBY_LDSHARED"] = "$(CC) -shared  -fPIC"
   CONFIG["LIBRUBY_DLDFLAGS"] = ""
-  CONFIG["RUBY_INSTALL_NAME"] = "ruby"
   CONFIG["rubyw_install_name"] = ""
   CONFIG["RUBYW_INSTALL_NAME"] = ""
-  CONFIG["RUBY_SO_NAME"] = "$(RUBY_INSTALL_NAME)"
   CONFIG["LIBRUBY_A"] = "lib$(RUBY_SO_NAME)-static.a"
-  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_INSTALL_NAME).so.$(MAJOR).81"
+  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_INSTALL_NAME).so.1.85"
   CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_SO_NAME).so"
   CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
   CONFIG["LIBRUBYARG"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["LIBRUBYARG_STATIC"] = "-l$(RUBY_SO_NAME)-static"
-  CONFIG["LIBRUBYARG_SHARED"] = "-l$(RUBY_SO_NAME)"
+  CONFIG["LIBRUBYARG_SHARED"] = "-Wl,-R -Wl,$(libdir) -L$(libdir) -L. -l$(RUBY_SO_NAME)"
   CONFIG["SOLIBS"] = "$(LIBS)"
   CONFIG["DLDLIBS"] = " -lc"
   CONFIG["ENABLE_SHARED"] = "yes"
@@ -122,36 +139,35 @@ module Config
   CONFIG["COMMON_MACROS"] = ""
   CONFIG["COMMON_HEADERS"] = ""
   CONFIG["EXPORT_PREFIX"] = ""
+  CONFIG["MINIOBJS"] = ""
+  CONFIG["PREINSTALL"] = ""
   CONFIG["MAKEFILES"] = "Makefile"
-  CONFIG["arch"] = "hppa-openbsd3.6"
-  CONFIG["sitearch"] = "hppa-openbsd3.6"
+  CONFIG["arch"] = "hppa-openbsd4.2"
+  CONFIG["sitearch"] = "hppa-openbsd4.2"
   CONFIG["sitedir"] = "$(prefix)/lib/ruby/site_ruby"
-  CONFIG["configure_args"] = "'--enable-shared' '--without-x11' '--prefix=/usr/local' '--sysconfdir=/etc' 'CC=cc' 'CFLAGS=-O2  '"
+  CONFIG["configure_args"] = " '--enable-shared' '--enable-ipv6' '--with-dbm-type=bogus' '--with-opt-dir=/usr/local' '--with-tcl-include=/usr/local/include/tcl8.4' '--with-tk-include=/usr/local/include/tk8.4' '--with-X11-dir=/usr/X11R6' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' 'CC=cc' 'CFLAGS=-O2 -pipe' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE' 'YACC=yacc'"
   CONFIG["NROFF"] = "/usr/bin/nroff"
   CONFIG["MANTYPE"] = "doc"
   CONFIG["LTLIBOBJS"] = ""
-  CONFIG["abs_srcdir"] = "$(ac_abs_srcdir)"
-  CONFIG["abs_top_srcdir"] = "$(ac_abs_top_srcdir)"
-  CONFIG["builddir"] = "$(ac_builddir)"
-  CONFIG["abs_builddir"] = "$(ac_abs_builddir)"
-  CONFIG["top_builddir"] = "$(ac_top_builddir)"
-  CONFIG["abs_top_builddir"] = "$(ac_abs_top_builddir)"
   CONFIG["ruby_version"] = "$(MAJOR).$(MINOR)"
   CONFIG["rubylibdir"] = "$(libdir)/ruby/$(ruby_version)"
   CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["sitelibdir"] = "$(sitedir)/$(ruby_version)"
   CONFIG["sitearchdir"] = "$(sitelibdir)/$(sitearch)"
-  CONFIG["compile_dir"] = "/usr/obj/ports/ruby-1.8.1/ruby-1.8.1"
+  CONFIG["topdir"] = File.dirname(__FILE__)
   MAKEFILE_CONFIG = {}
   CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
   def Config::expand(val, config = CONFIG)
     val.gsub!(/\$\$|\$\(([^()]+)\)|\$\{([^{}]+)\}/) do |var|
       if !(v = $1 || $2)
 	'$'
-      elsif key = config[v]
+      elsif key = config[v = v[/\A[^:]+(?=(?::(.*?)=(.*))?\z)/]]
+	pat, sub = $1, $2
 	config[v] = false
-        Config::expand(key, config)
+	Config::expand(key, config)
 	config[v] = key
+	key = key.gsub(/#{Regexp.quote(pat)}(?=\s|\z)/n) {sub} if pat
+	key
       else
 	var
       end
@@ -162,4 +178,5 @@ module Config
     Config::expand(val)
   end
 end
+RbConfig = Config # compatibility for ruby-1.9
 CROSS_COMPILING = nil unless defined? CROSS_COMPILING
