@@ -1,4 +1,3 @@
-
 #define PACKAGE_NAME ""
 #define PACKAGE_TARNAME ""
 #define PACKAGE_VERSION ""
@@ -62,6 +61,7 @@
 #define HAVE_FLOAT_H 1
 #define HAVE_IEEEFP_H 1
 #define HAVE_PTHREAD_H 1
+#define SIZEOF_RLIM_T 8
 #define HAVE_STRUCT_STAT_ST_BLKSIZE 1
 #define HAVE_ST_BLKSIZE 1
 #define HAVE_STRUCT_STAT_ST_BLOCKS 1
@@ -128,6 +128,8 @@
 #define HAVE_SETGROUPS 1
 #define HAVE_GETPRIORITY 1
 #define HAVE_GETRLIMIT 1
+#define HAVE_SETRLIMIT 1
+#define HAVE_SYSCONF 1
 #define HAVE_DLOPEN 1
 #define HAVE_SIGPROCMASK 1
 #define HAVE_SIGACTION 1
@@ -143,6 +145,8 @@
 #define HAVE_TANH 1
 #define HAVE_SETUID 1
 #define HAVE_SETGID 1
+#define HAVE_SETENV 1
+#define HAVE_UNSETENV 1
 #define HAVE_STRUCT_TM_TM_ZONE 1
 #define HAVE_TM_ZONE 1
 #define HAVE_STRUCT_TM_TM_GMTOFF 1
@@ -153,6 +157,7 @@
 #define FILE_COUNT _r
 #define FILE_READPTR _p
 #define NEED_IO_SEEK_BETWEEN_RW 1
+#define HAVE__SC_CLK_TCK 1
 #define STACK_GROW_DIRECTION -1
 #define DEFAULT_KCODE KCODE_NONE
 #define USE_ELF 1
@@ -160,6 +165,6 @@
 #define RUBY_LIB "/usr/local/lib/ruby/1.8"
 #define RUBY_SITE_LIB "/usr/local/lib/ruby/site_ruby"
 #define RUBY_SITE_LIB2 "/usr/local/lib/ruby/site_ruby/1.8"
-#define RUBY_PLATFORM "i386-openbsd3.9"
-#define RUBY_ARCHLIB "/usr/local/lib/ruby/1.8/i386-openbsd3.9"
-#define RUBY_SITE_ARCHLIB "/usr/local/lib/ruby/site_ruby/1.8/i386-openbsd3.9"
+#define RUBY_PLATFORM "i386-openbsd4.1"
+#define RUBY_ARCHLIB "/usr/local/lib/ruby/1.8/i386-openbsd4.1"
+#define RUBY_SITE_ARCHLIB "/usr/local/lib/ruby/site_ruby/1.8/i386-openbsd4.1"
